@@ -13,11 +13,9 @@ package deploy
 
 import (
 	orgv1 "github.com/eclipse/che-operator/pkg/apis/org/v1"
-	"github.com/eclipse/che-operator/pkg/util"
 )
 
 func GetLabels(cr *orgv1.CheCluster, component string) (labels map[string]string) {
-	cheFlavor := util.GetValue(cr.Spec.Server.CheFlavor, DefaultCheFlavor)
-	labels = map[string]string{"app": cheFlavor, "component": component}
+	labels = map[string]string{"app": DefaultCheFlavor(cr), "component": component}
 	return labels
 }
